@@ -5,14 +5,14 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef PIMCOMMON_ACLENTRYDIALOG_P_H
-#define PIMCOMMON_ACLENTRYDIALOG_P_H
+#pragma once
 
 #include <KIMAP/Acl>
 
 #include <QDialog>
 
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @short A dialog for editing an IMAP ACL entry.
  */
@@ -31,7 +31,7 @@ public:
     /**
      * Destroys the ACL entry dialog.
      */
-    ~AclEntryDialog();
+    ~AclEntryDialog() override;
 
     /**
      * Sets the user @p id of the ACL entry.
@@ -62,4 +62,3 @@ private:
 };
 }
 
-#endif
